@@ -25,7 +25,7 @@ def request(api, params):
         raise Exception(repDic["msg"])
     if repDic["data"]["err"] != 0:
         raise Exception(repDic["data"]["msg"])
-    return repDic["data"]["res"]
+    return repDic
 
 """
 文件上传
@@ -36,5 +36,21 @@ def request(api, params):
 异常:
   文件不存在
 """
-def upload(fileName):
-    return uploader.XesUploader().upload(fileName)
\ No newline at end of file
+def uploadFile(fileName):
+    return uploader.XesUploader().upload(fileName)
+
+
+"""
+文件下载
+参数:
+  url - string，文件地址，例如"https://livefile.xesimg.com/programme/python_assets/26242386b1788c8ca9a24c5c9520b864.png"
+  fileName - string，保存到本地的文件名，例如"abc.png"
+返回值:
+  无
+异常:
+  文件地址异常
+"""
+def downloadFile(url, fileName):
+    r = requests.get(url, stream=True)
+    with open(fileName, 'wb') as file:
+        file.write(r.content)
\ No newline at end of file
